@@ -36,6 +36,16 @@ where
         }
     }
 
+    #[inline(always)]
+    pub fn root_ref(&self) -> TreeResult<&Node<D>> {
+        Ok(self.node_ref(NodeIdx::ROOT)?)
+    }
+
+    #[inline(always)]
+    pub fn root_mut(&mut self) -> TreeResult<&mut Node<D>> {
+        Ok(self.node_mut(NodeIdx::ROOT)?)
+    }
+
     #[inline(always)]
     pub fn node_ref(&self, idx: NodeIdx) -> TreeResult<&Node<D>> {
         self.nodes
@@ -183,6 +193,26 @@ where
     }
 }
 
+impl<D> std::ops::Index<NodeIdx> for ArenaTree<D>
+where
+    D: Clone + Debug + Default + PartialEq,
+{
+    type Output = Node<D>;
+
+    fn index(&self, idx: NodeIdx) -> &Self::Output {
+        unsafe { self.nodes.get_unchecked(idx.0) }
+    }
+}
+
+impl<D> std::ops::IndexMut<NodeIdx> for ArenaTree<D>
+where
+    D: Clone + Debug + Default + PartialEq,
+{
+    fn index_mut(&mut self, idx: NodeIdx) -> &mut Self::Output {
+        unsafe { self.nodes.get_unchecked_mut(idx.0) }
+    }
+}
+
 impl<D> fmt::Display for ArenaTree<D>
 where
     D: Clone + Debug + Default + PartialEq,
@@ -346,13 +376,29 @@ where
     }
 }
 
-#[derive(Clone, Debug, PartialEq, serde_derive::Serialize, serde_derive::Deserialize)]
+#[rustfmt::skip]
+#[derive(
+    Clone,
+    Debug,
+    PartialEq,
+    serde_derive::Serialize,
+    serde_derive::Deserialize
+)]
 pub struct ArenaTreeDelta<D>(Option<ArenaTree<D>>)
 where
     D: Clone + Debug + Default + PartialEq + Core;
 
+#[rustfmt::skip]
 #[derive(
-    Clone, PartialEq, Eq, PartialOrd, Ord, Hash, deltoid_derive::Delta, Deserialize, Serialize,
+    Clone,
+    PartialEq,
+    Eq,
+    PartialOrd,
+    Ord,
+    Hash,
+    deltoid_derive::Delta,
+    Deserialize,
+    Serialize,
 )]
 pub struct Node<D> {
     idx: NodeIdx,
@@ -431,8 +477,18 @@ impl<D: Debug> fmt::Debug for Node<D> {
     }
 }
 
+#[rustfmt::skip]
 #[derive(
-    Clone, Copy, PartialEq, Eq, PartialOrd, Ord, Hash, deltoid_derive::Delta, Deserialize, Serialize,
+    Clone,
+    Copy,
+    PartialEq,
+    Eq,
+    PartialOrd,
+    Ord,
+    Hash,
+    deltoid_derive::Delta,
+    Deserialize,
+    Serialize,
 )]
 pub struct NodeIdx(pub(crate) usize);
 
